import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(name="tomosuitepy",
      version=read("VERSION.txt"),
      description="",
      long_description=read('README.md'),
      long_description_content_type='text/markdown',
      author="William Judge",
      author_email="williamjudge94@gmail.com",
      url="https://github.com/WilliamJudge94/tomosuitepy",
      keywords="Tomography CT X-ray microscopy Argonne Advanced Photon Source",
      install_requires=[
      ],
      python_requires='==3.6',
      packages=['tomosuitepy',],
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
          'Natural Language :: English',
          'Operating System :: POSIX :: Linux',
          'Programming Language :: Python :: 3.6',
          'Topic :: Scientific/Engineering :: Chemistry',
          'Topic :: Scientific/Engineering :: Physics',
          'Topic :: Scientific/Engineering :: Visualization',
      ]
)


import sys
import os
sys.path.append(os.path.dirname(__file__))
sys.path.append(f'{os.path.dirname(__file__)}/hard_networks/TomoGAN/')
sys.path.append(f'{os.path.dirname(__file__)}/hard_networks/generative_inpainting/')
sys.path.append(f'{os.path.dirname(__file__)}/hard_networks/noise2noise/')

import imageio
import numpy as np
from tqdm import tqdm
import tifffile as tif
import matplotlib.pyplot as plt

#from tomosuite.base.common import load_extracted_prj, load_extracted_theta, skip_lowdose
#from tomosuite.base.start_project import start_project
#from tomosuite.base.extract_projections import extract
#from tomosuite.base.reconstruct import reconstruct_data_tomogan, reconstruct_data_deepfillv2, plot_reconstruction


#from tomosuite.low_dose.data_prep import setup_tomogan_fake_noise, noise_test_tomogan
#from tomosuite.low_dose.tomogan import train_tomogan, predict_tomogan, save_noise_tomogan


#from tomosuite.inpainting.data_prep import *
#from tomosuite.inpainting.inpainting import *
